==> rdd_2.0.7.orig.tar.gz: rdd-2.0.7/src/commandline.h <==
/*
 * Copyright (c) 2002 - 2006, Netherlands Forensic Institute
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */



#ifndef __commandline_h__
#define __commandline_h__

#define flag_set(word, bit)   (((word) & (bit)) != 0)

typedef struct _RDD_OPTION {
	char     *short_name;
	char     *long_name;
	char     *arg_descr;
	unsigned  valid_modes;
	char     *description;
	unsigned  count;
	char     *arg_value;
} RDD_OPTION;

/**
 * Verify whether argv[*i] is an option name (short or long) and
 * whether its argument, if any, is present.
 */
void        rdd_opt_init(RDD_OPTION *opttab, const char *usage_msg);

RDD_OPTION *rdd_get_opt_with_arg(char **argv, int argc,
				unsigned *i, char **opt, char **arg);

int         rdd_opt_set_arg(char *longname, char **argp);

int         rdd_opt_set(char *longname);

void        rdd_opt_usage(void);

#endif /* __commandline_h__ */

==> rdd-3.0.4.tar.gz: rdd-3.0.4/src/commandline.h <==
/*
 * Copyright (c) 2002 - 2006, Netherlands Forensic Institute
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */



/*
 * $Author: raoul $
 * $LastChangedBy: kojak $
 * $LastChangedDate: 2002-12-30 11:22:51 +0100 (Mon, 30 Dec 2002) $
 */

#ifndef __commandline_h__
#define __commandline_h__

#define flag_set(word, bit)   (((word) & (bit)) != 0)

typedef struct _RDD_OPTION {
	char     *short_name;
	char     *long_name;
	char     *arg_descr;
	unsigned  valid_modes;
	char     *description;
	unsigned  count;
	char     *arg_value;
} RDD_OPTION;

/**
 * Verify whether argv[*i] is an option name (short or long) and
 * whether its argument, if any, is present.
 */
void        rdd_opt_init(const char *usage_msg);

RDD_OPTION *rdd_get_opt_with_arg(RDD_OPTION * tab, char **argv, int argc,
				unsigned *i, char **opt, char **arg);

int         rdd_opt_set_arg(RDD_OPTION * tab, char *longname, char **argp);

int         rdd_opt_set(RDD_OPTION * tab, char *longname);

void        rdd_opt_usage(RDD_OPTION * opttab, RDD_OPTION * output_opttab, int returnCode);

int         compare_paths(char *first_path, char *second_path);


#endif /* __commandline_h__ */
